@@ -5,7 +5,7 @@ use Catmandu::Store::Solr;
 use Catmandu;
 use Moo;
 
-our $VERSION = '0.02153';
+our $VERSION = '0.02154';
 
 with 'Catmandu::Importer';
 
@@ -40,10 +40,10 @@ sub generator {
         state $total = 100;
         state $hits = [];
 
-        return if $start >= $total;
-
         unless(scalar(@$hits)){
 
+            return if $start >= $total;
+
             my $res = $self->_bag()->search(
                 query => $self->query,
                 fq => $self->fq,
@@ -51,7 +51,8 @@ sub generator {
                 limit => $limit,
                 fl => $self->fl,
                 facet => "false",
-                spellcheck => "false"
+                spellcheck => "false",
+                sort => $self->id_field()." asc"
             );
             $total = $res->total;
             $hits = $res->hits();
